@@ -6,7 +6,7 @@ use Carp;
 
 require 5.005;
 
-$VERSION = '3.03_02';
+$VERSION = '3.01';
 $VERSION = eval $VERSION; # modperlstyle: convert the string into a number
 
 # Remember subclasses we have "wrapped" submit() with _pre_submit()
@@ -33,12 +33,8 @@ my @methods = qw(
     response_code
     response_header
     response_page
-    avs_code
-    cvv2_response
 );
 
-__PACKAGE__->build_subs(@methods);
-
 #fallback
 sub _info {
   my $class = shift;
@@ -54,16 +50,16 @@ sub _info {
 %_info_handler = (
   'supported_types'   => sub {
     my( $class, $v ) = @_;
-    my $types = ref($v) ? $v : defined($v) ? [ $v ] : [];
-    $types = { map { $_=>1 } @$types } if ref($types) eq 'ARRAY';
+    my $types = ref($v) ? $v : [ $v ];
+    $types = { map { $_=>1 } @$types } if ref($v) eq 'ARRAY';
     $types;
   },
   'supported_actions' => sub {
     my( $class, $v ) = @_;
-    return %$v if ref($v) eq 'HASH';
+    return $v if ref($v) eq 'HASH';
     $v = [ $v ] unless ref($v);
-    my $types = $class->info('supported_types') || {};
-    ( map { $_ => $v } keys %$types );
+    my $types = $class->info('supported_types');
+    { map { $_ => $v } keys %$types };
   },
 );
 
@@ -90,6 +86,7 @@ sub new {
     croak("unknown processor $processor ($@)") if $@;
 
     my $self = bless {processor => $processor}, $subclass;
+    $self->build_subs(@methods);
 
     if($self->can("set_defaults")) {
         $self->set_defaults(%data);
@@ -160,6 +157,7 @@ sub _pre_submit {
               unless ( $@ =~ m/^Can\'t locate/ );
         } else {
             my $risk_tx = bless( { processor => $fraud_detection }, $subclass );
+            $risk_tx->build_subs(@methods);
             if ($risk_tx->can('set_defaults')) {
                 $risk_tx->set_defaults();
             }
@@ -272,24 +270,15 @@ Business::OnlinePayment - Perl extension for online payment processing
                         type        => 'Visa',
                         amount      => '49.95',
                         card_number => '1234123412341238',
-                        expiration  => '06/15',
+                        expiration  => '0100',
                         name        => 'John Q Doe',
                        );
-
-  eval { $transaction->submit(); };
-
-  if ( $@ ) {
-
-    print "$processor error: $@\n";
-
-  } else {
+  $transaction->submit();
   
-    if ( $transaction->is_success() ) {
-      print "Card processed successfully: ". $transaction->authorization()."\n";
-    } else {
-      print "Card was rejected: ". $transaction->error_message(). "\n";
-    }
-
+  if($transaction->is_success()) {
+    print "Card processed successfully: ", $transaction->authorization(), "\n";
+  } else {
+    print "Card was rejected: ", $transaction->error_message(), "\n";
   }
 
 =head1 DESCRIPTION
@@ -356,8 +345,6 @@ What action being taken by this transaction. Currently available are:
 
 =item Post Authorization
 
-=item Reverse Authorization
-
 =item Void
 
 =item Credit
@@ -411,11 +398,6 @@ Duty amount (portion of amount field, not added to it).
 
 Tax exempt flag (i.e. TRUE, FALSE, T, F, YES, NO, Y, N, 1, 0).
 
-=item currency
-
-Currency, specified as an ISO 4217 three-letter code, such as USD, CAD, EUR,
-AUD, DKK, GBP, JPY, NZD, etc.
-
 =back
 
 =head3 CUSTOMER INFO FIELDS
@@ -512,7 +494,7 @@ Credit card number.
 
 =item expiration
 
-Credit card expiration, MM/YY.
+Credit card expiration.
 
 =item cvv2
 
@@ -540,7 +522,7 @@ Track 1 on the magnetic stripe (Card present only)
 
 Track 2 on the magnetic stripe (Card present only)
 
-=item recurring_billing
+=item recurring billing
 
 Recurring billing flag
 
@@ -640,19 +622,14 @@ verification (if the processor supports it).
 
 =head2 submit()
 
-Submit the transaction to the processor for completion.
-
-If there is a gateway communication error or other "meta" , the submit method
-will throw a fatal exception.  You can catch this with eval {} if you would
-like to treat gateway co
+Submit the transaction to the processor for completion
 
 =head1 TRANSACTION RESULT METHODS
 
 =head2 is_success()
 
-Returns true if the transaction was approved by the gateway, false if 
-it was submitted but not approved, or undef if it has not been 
-submitted yet.
+Returns true if the transaction was submitted successfully, false if
+it failed (or undef if it has not been submitted yet).
 
 =head2 error_message()
 
@@ -668,8 +645,10 @@ are: "expired", "nsf" (non-sufficient funds), "stolen", "pickup",
 "blacklisted" and "declined" (card/transaction declines only, not
 other errors).
 
-Note that not all processor modules support this, and that if supported,
-it may not be set for all declines.
+Note that (as of Aug 2006) this is only supported by some of the
+newest processor modules, and that, even if supported, a failure
+status is an entirely optional field that is only set for specific
+kinds of failures.
 
 =head2 authorization()
 
@@ -790,7 +769,7 @@ Phil Lobbes E<lt>phil at perkpartners dot comE<gt>
 
 Copyright (c) 1999-2004 Jason Kohles
 Copyright (c) 2004 Ivan Kohler
-Copyright (c) 2007-2014 Freeside Internet Services, Inc.
+Copyright (c) 2007-2010 Freeside Internet Services, Inc.
 
 All rights reserved.
 
@@ -810,18 +789,21 @@ http://420.am/cgi-bin/mailman/listinfo/bop-devel/
 
 =head1 REPOSITORY
 
-The code is available from our public git repository:
+The code is available from our public CVS repository:
 
-  git clone git://git.freeside.biz/Business-OnlinePayment.git
+  export CVSROOT=":pserver:anonymous@cvs.freeside.biz:/home/cvs/cvsroot"
+  cvs login
+  # The password for the user `anonymous' is `anonymous'.
+  cvs checkout Business-OnlinePayment
 
 Or on the web:
 
-  http://freeside.biz/gitweb/?p=Business-OnlinePayment.git
+  http://freeside.biz/cgi-bin/viewvc.cgi/Business-OnlinePayment/
 
 Many (but by no means all!) processor plugins are also available in the same
 repository, see:
 
-  http://freeside.biz/gitweb/
+  http://freeside.biz/cgi-bin/viewvc.cgi/
 
 =head1 DISCLAIMER
 
